@@ -14,11 +14,11 @@
 template <class T>
 py::array_t<T> array_like(py::object obj) {
     if(!py::isinstance<py::array>(obj)) {
-        ssize_t shape[1] = {0}; // if scalar
+        py::ssize_t shape[1] = {0}; // if scalar
         if(py::isinstance<py::sequence>(obj) && !py::isinstance<py::str>(obj)) {
             // if sequence
             auto seq = py::cast<py::sequence>(obj);
-            shape[0] = static_cast<ssize_t>(seq.size());
+            shape[0] = static_cast<py::ssize_t>(seq.size());
         }
         return py::array_t<T>(shape);
     }
