@@ -9,6 +9,7 @@
 
 #include <boost/core/nvp.hpp>
 #include <boost/histogram/axis/regular.hpp>
+#include <utility>
 
 #include <pybind11/functional.h>
 
@@ -28,7 +29,7 @@ struct func_transform {
     py::str _name;          // Optional name (uses repr from objects otherwise)
 
     /// Convert an object into a std::function. Can handle ctypes
-    /// function pointers and PyBind11 C++ functions, or anything
+    /// function pointers and pybind11 C++ functions, or anything
     /// else with a defined convert function
     std::tuple<raw_t*, py::object> compute(py::object& input) {
         // Run the conversion function on the input (unless conversion is None)
@@ -57,7 +58,7 @@ struct func_transform {
             return std::make_tuple(ptr, src);
         }
 
-        // If we made it to this point, we probably have a C++ PyBind object or an
+        // If we made it to this point, we probably have a C++ pybind object or an
         // invalid object. The following is based on the std::function conversion in
         // pybind11/functional.hpp
         if(!py::isinstance<py::function>(src))
@@ -69,7 +70,9 @@ struct func_transform {
         if(auto cfunc = func.cpp_function()) {
             auto c = py::reinterpret_borrow<py::capsule>(
                 PyCFunction_GET_SELF(cfunc.ptr()));
-            auto rec = (py::detail::function_record*)c;
+
+            // NOLINTNEXTLINE(google-readability-casting)
+            auto rec = (py::detail::function_record*)(c);
 
             if(rec && rec->is_stateless
                && py::detail::same_type(
@@ -78,7 +81,8 @@ struct func_transform {
                 struct capture {
                     raw_t* f;
                 };
-                return std::make_tuple(((capture*)&rec->data)->f, src);
+                return std::make_tuple((reinterpret_cast<capture*>(&rec->data))->f,
+                                       src);
             }
 
             // Note that each error is slighly different just to help with debugging
@@ -93,8 +97,8 @@ struct func_transform {
     func_transform(py::object f, py::object i, py::object c, py::str n)
         : _forward_ob(f)
         , _inverse_ob(i)
-        , _convert_ob(c)
-        , _name(n) {
+        , _convert_ob(std::move(c))
+        , _name(std::move(n)) {
         std::tie(_forward, _forward_converted) = compute(f);
         std::tie(_inverse, _inverse_converted) = compute(i);
     }
